<?php
namespace net\xmp\phpbook;

/**
 * Query of all products whose name starts with $name.
 * @return array Data for the HTML table
 */
function getProductsByName($name) {
    $db = new DatabaseConnection();
    $db->connect();
    // Select products by name and list price
    $query = 'SELECT ProductID, Name, ListPrice
              FROM SalesLT.Product WHERE Name LIKE ?
              ORDER BY Name';
    $params = array($name . '%');
    // Run query
    $stmt = sqlsrv_query($db->handle, $query, $params);
    if ($stmt === false) {
        $db->exitWithError('Product data query failed.');
    }
    if (!sqlsrv_has_rows($stmt)) {
        return false; // No hits in the database (empty result)
    }
    // Retrieve individual rows from the result
    $table = array(array('ID', 'Product', 'List Price'));
    while ($row = sqlsrv_fetch_array($stmt)) {
        $table[] = array($row['ProductID'], $row['Name'],
            $row['ListPrice']);
    }
    // null == no more rows, false == Error
    if ($row === false) {
        $db->exitWithError('Retrieving product data entry failed.');
    }
    sqlsrv_free_stmt($stmt);
    $db->close();
    return $table;
}
?>
