/* getCreditPrice:
 * Calculates the product price for a credit purchase
 */
CREATE PROC SalesLT.getCreditPrice
  @id int,                          -- SalesLT.Product.ProductId
  @rate real,                       -- Monthly interest rate
  @months int = 12,                 -- Number of months
  @listPrice money OUTPUT,
  @price money OUTPUT
AS
  DECLARE @fee money;               -- Definition of a local variable for fees
  SET @price = (
    SELECT ListPrice FROM SalesLT.Product 
    WHERE ProductID = @id);
  SET @listPrice = @price;
  SET @fee = CASE                   -- Fees depend on product price
    WHEN @price < 10.0 THEN 0.50
    WHEN @price < 50.0 THEN 1.00
    ELSE                    2.00
  END;
  IF (@months >= 24) BEGIN          -- If credit period is over 2 years, the fee doubles
    SET @fee *= 2;
  END
  WHILE (@months > 0) BEGIN         -- Calculating the interest and compound interest
    SET @price = @price * (1+@rate);
    SET @months -= 1;
  END
  SET @price += @fee;
GO
