class LDAPConnection {

    // ...
    public $baseDN = '';
    // ...

    /**
     * Retrieving an entry with the SAM account name
     * @param string $account SAM account name
     * @param array $attributes Wanted attribute
     * @param string $baseDN Basic DN for the search
     */
    function getAccount($account, $attributes=array(), $baseDN='') {
        $filter = '(sAMAccountName=' . escapeLDAP($account) . ')';
        $account = $this->getOneEntry($filter, $attributes, $baseDN);
        if (!$account) {
            $this->exitWithError('Account not found.');
        }
        return $account;
    }

    /**
     * Retrieving a search entry
     * @param string $filter Filter string
     * @param array $attributes Wanted attribute
     * @param string $baseDN Basic DN for the search
     */
    function getOneEntry($filter, $attributes=array(), $baseDN='') {
        if (empty($baseDN)) {
            $baseDN = $this->baseDN;
        }
        $result = ldap_search($this->handle, $baseDN, $filter, $attributes);
        if (!$result) {
            return false;
        }
        $entry = ldap_first_entry($this->handle, $result);
        if (!$entry) {
            return false;
        }
        $attr = ldap_get_attributes($this->handle, $entry);
        if (!$attr) {
            return false;
        }
        $attr['dn'] = ldap_get_dn($this->handle, $entry);
        return $attr;
    }
}
